==> sdo-eclipselink-plugin-2.3.6-sources.jar: com/sun/xml/ws/db/sdo/SDOWrapperAccessor.java <==
/*
 * Copyright (c) 2012, 2019 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.db.sdo;

import commonj.sdo.DataObject;
import commonj.sdo.Property;
import commonj.sdo.Type;
import commonj.sdo.helper.TypeHelper;

import com.sun.xml.ws.spi.db.PropertyGetter;
import com.sun.xml.ws.spi.db.PropertySetter;

import javax.xml.namespace.QName;

import com.sun.xml.ws.spi.db.PropertyAccessor;
import com.sun.xml.ws.spi.db.WrapperAccessor;

import java.util.HashMap;
import java.util.HashSet;
import java.util.List;

/**
 * Created by IntelliJ IDEA.
 * User: giglee
 * Date: May 19, 2009
 * Time: 10:40:31 AM
 * To change this template use File | Settings | File Templates.
 */
public final class SDOWrapperAccessor extends WrapperAccessor {

    private SDOContextWrapper contextWrapper = null;
    private Class<?> contentClass;

    public SDOWrapperAccessor(SDOContextWrapper contextWrapper, Class<?> wrapperBean) {
        this.contextWrapper = contextWrapper;
        contentClass = wrapperBean;
        initBuilders();
    }

    protected void initBuilders() {
        HashMap<Object, PropertySetter> setByQName = new HashMap<Object, PropertySetter>();
        HashMap<Object, PropertyGetter> getByQName = new HashMap<Object, PropertyGetter>();
        HashMap<Object, PropertySetter> setByLocalpart = new HashMap<Object, PropertySetter>();
        HashMap<Object, PropertyGetter> getByLocalpart = new HashMap<Object, PropertyGetter>();

        HashSet<String> elementLocalNames = new HashSet<String>();

        TypeHelper helper = contextWrapper.getHelperContext().getTypeHelper();
        Type type = helper.getType(contentClass);

        @SuppressWarnings("unchecked")
        List<Property> properties = (List<Property>) type.getDeclaredProperties();
        for (Property p : properties) {
            QName qname = SDOUtils.getPropertyElementName(contextWrapper.getHelperContext(), p);
            SDOPropertyBuilder pBuilder = new SDOPropertyBuilder(qname, p.getType().getInstanceClass());
            setByQName.put(qname, pBuilder);
            getByQName.put(qname, pBuilder);
            setByLocalpart.put(qname.getLocalPart(), pBuilder);
            getByLocalpart.put(qname.getLocalPart(), pBuilder);
            if (elementLocalNames.contains(qname.getLocalPart())) {
                elementLocalNameCollision = true;
            } else {
                elementLocalNames.add(qname.getLocalPart());
            }
        }

        if (elementLocalNameCollision) {
            propertySetters = setByQName;
            propertyGetters = getByQName;

        } else {
            propertySetters = setByLocalpart;
            propertyGetters = getByLocalpart;
        }
    }

    /**
     * Knows the mapping of all the properties of a contaning type
     */
    static class SDOPropertyBuilder implements PropertyAccessor,
            PropertyGetter, PropertySetter {

        private QName qname;
        private Class type;

        public SDOPropertyBuilder(QName qname, Class type) {
            this.qname = qname;
            this.type = type;
        }

        @Override
        public Class getType() {
            return type;
        }

        @Override
        public <A> A getAnnotation(Class<A> annotationType) {
            return null;  //To change body of implemented methods use File | Settings | File Templates.
        }

        // get the property value from the wrapper intance
        @Override
        public Object get(Object instance) {
            if (instance instanceof DataObject) {
                DataObject wrapperBean = (DataObject) instance;
                Property p = wrapperBean.getInstanceProperty(qname.getLocalPart());
                if (p == null) {
                    throw new SDODatabindingException("Property not found: " + qname.getLocalPart());
                }
                Object o = wrapperBean.get(p);
                return SDOUtils.unwrapPrimitives(o);
            } else {
                throw new SDODatabindingException("Invalid SDO object: " + instance);
            }
        }

        // set the property of the instance to the value
        @Override
        public void set(Object instance, Object value) {
            if (instance instanceof DataObject) {
                DataObject wrapperBean = (DataObject) instance;
                Property p = wrapperBean.getInstanceProperty(qname.getLocalPart());
                if (p == null) {
                    throw new SDODatabindingException("Property not found: " + qname.getLocalPart());
                }
                wrapperBean.set(p, value);
            } else {
                throw new SDODatabindingException("Invalid SDO object: " + instance);

            }
        }
    }
}

==> sdo-eclipselink-plugin-4.0.3-sources.jar: com/sun/xml/ws/db/sdo/SDOWrapperAccessor.java <==
/*
 * Copyright (c) 2012, 2022 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.db.sdo;

import commonj.sdo.DataObject;
import commonj.sdo.Property;
import commonj.sdo.Type;
import commonj.sdo.helper.TypeHelper;

import com.sun.xml.ws.spi.db.PropertyGetter;
import com.sun.xml.ws.spi.db.PropertySetter;

import javax.xml.namespace.QName;

import com.sun.xml.ws.spi.db.PropertyAccessor;
import com.sun.xml.ws.spi.db.WrapperAccessor;

import java.util.HashMap;
import java.util.HashSet;
import java.util.List;

/**
 * Created by IntelliJ IDEA.
 * User: giglee
 * Date: May 19, 2009
 * Time: 10:40:31 AM
 * To change this template use File | Settings | File Templates.
 */
public final class SDOWrapperAccessor extends WrapperAccessor {

    private SDOContextWrapper contextWrapper = null;
    private Class<?> contentClass;

    public SDOWrapperAccessor(SDOContextWrapper contextWrapper, Class<?> wrapperBean) {
        this.contextWrapper = contextWrapper;
        contentClass = wrapperBean;
        initBuilders();
    }

    protected void initBuilders() {
        HashMap<Object, PropertySetter> setByQName = new HashMap<>();
        HashMap<Object, PropertyGetter> getByQName = new HashMap<>();
        HashMap<Object, PropertySetter> setByLocalpart = new HashMap<>();
        HashMap<Object, PropertyGetter> getByLocalpart = new HashMap<>();

        HashSet<String> elementLocalNames = new HashSet<>();

        TypeHelper helper = contextWrapper.getHelperContext().getTypeHelper();
        Type type = helper.getType(contentClass);

        @SuppressWarnings("unchecked")
        List<Property> properties = (List<Property>) type.getDeclaredProperties();
        for (Property p : properties) {
            QName qname = SDOUtils.getPropertyElementName(contextWrapper.getHelperContext(), p);
            SDOPropertyBuilder pBuilder = new SDOPropertyBuilder(qname, p.getType().getInstanceClass());
            setByQName.put(qname, pBuilder);
            getByQName.put(qname, pBuilder);
            setByLocalpart.put(qname.getLocalPart(), pBuilder);
            getByLocalpart.put(qname.getLocalPart(), pBuilder);
            if (elementLocalNames.contains(qname.getLocalPart())) {
                elementLocalNameCollision = true;
            } else {
                elementLocalNames.add(qname.getLocalPart());
            }
        }

        if (elementLocalNameCollision) {
            propertySetters = setByQName;
            propertyGetters = getByQName;

        } else {
            propertySetters = setByLocalpart;
            propertyGetters = getByLocalpart;
        }
    }

    /**
     * Knows the mapping of all the properties of a contaning type
     */
    static class SDOPropertyBuilder implements PropertyAccessor,
            PropertyGetter, PropertySetter {

        private QName qname;
        private Class<?> type;

        public SDOPropertyBuilder(QName qname, Class<?> type) {
            this.qname = qname;
            this.type = type;
        }

        @Override
        public Class getType() {
            return type;
        }

        @Override
        public <A> A getAnnotation(Class<A> annotationType) {
            return null;  //To change body of implemented methods use File | Settings | File Templates.
        }

        // get the property value from the wrapper intance
        @Override
        public Object get(Object instance) {
            if (instance instanceof DataObject) {
                DataObject wrapperBean = (DataObject) instance;
                Property p = wrapperBean.getInstanceProperty(qname.getLocalPart());
                if (p == null) {
                    throw new SDODatabindingException("Property not found: " + qname.getLocalPart());
                }
                Object o = wrapperBean.get(p);
                return SDOUtils.unwrapPrimitives(o);
            } else {
                throw new SDODatabindingException("Invalid SDO object: " + instance);
            }
        }

        // set the property of the instance to the value
        @Override
        public void set(Object instance, Object value) {
            if (instance instanceof DataObject) {
                DataObject wrapperBean = (DataObject) instance;
                Property p = wrapperBean.getInstanceProperty(qname.getLocalPart());
                if (p == null) {
                    throw new SDODatabindingException("Property not found: " + qname.getLocalPart());
                }
                wrapperBean.set(p, value);
            } else {
                throw new SDODatabindingException("Invalid SDO object: " + instance);

            }
        }
    }
}
